@@ -182,14 +182,11 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
         test = "testIndLogistic";
         if( is.ordered(target) ) {
           dataInfo$target_type = "ordinal";
-          cat('\nTarget variable type: Ordinal')
         } else {
           if ( la == 2 ) {
             dataInfo$target_type = "binary"
-            cat('\nTarget variable type: Binomial')
           } else {
             dataInfo$target_type = "nominal"
-            cat('\nTarget variable type: Nominal')
           }
         }
         
@@ -215,15 +212,12 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
     if ( test == "testIndLogistic") {
       if ( is.ordered(target) )  {
         dataInfo$target_type = "ordinal";
-        cat('\nTarget variable type: Ordinal')
 
       } else {
         if ( la == 2 )  {
           dataInfo$target_type = "binary"
-          cat('\nTarget variable type: Binomial')
         } else {
           dataInfo$target_type = "nominal"
-          cat('\nTarget variable type: Nominal')
         }
       }
     }
