@@ -439,7 +439,7 @@ Internalmammpc = function(targ, data, statistic, max_k, threshold, test = NULL,
   flags = univariateModels$flag;
   #if we dont have any associations , return
   if ( min(pvalues , na.rm = TRUE) > threshold ) {
-    cat('No associations!');
+    #cat('No associations!');
     results = NULL;
     results$selectedVars = c();
     class(results$selectedVars) = "numeric";
