@@ -61,10 +61,10 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
   cs = dataset[ , csIndex];
   #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
-  if( length(cs) != 0 ) {
-    if( is.null(dim(cs)[2]) )  {   #cs is a vector
-      if(any(x != cs) == FALSE)  {  #if(!any(x == cs) == FALSE)
-        if( hash )  {   #update hash objects
+  if ( length(cs) != 0 ) {
+    if ( is.null(dim(cs)[2]) )  {   #cs is a vector
+      if ( identical(x, cs) )  {  #if(!any(x == cs) == FALSE)
+        if ( hash )  {   #update hash objects
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
         }
@@ -73,7 +73,7 @@ testIndRQ = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL
       }
     } else { #more than one var
       for (col in 1:dim(cs)[2])  {
-        if (any(x != cs[,col]) == FALSE)  {    #if(!any(x == cs) == FALSE)
+        if (identical(x, cs[, col]) )  {    #if(!any(x == cs) == FALSE)
           if ( hash ) {      #update hash objects
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
